combine_freq_results() combines the results of the frequency estimation
performed on single TCR clones (from the output of bagpipe) and
the frequency estimation performed on dual clones. The code will find the
rows of the single TCR frequency results that are represented by the dual
clones and replace them with the appropriate dual clone entry.
combine_freq_results(single, dual)freq_estimate is called)freq_estimate. If two single "clones" in the single
data.frame is represented by a dual clone in dual, then it is
removed and replaced with one row represented by the dual clone.