Learn R Programming

alphabetr (version 0.2.2)

dual_discrim_dual_likelihood: Calculate likelihood of two beta-sharing candidate alpha-beta pairs deriving from a dual clone

Description

dual_discrim_dual_likelihood() is used within dual_top to calculate the likelihood that two alpha-beta pairs identified by bagpipe sharing the same beta chain derive from a single dual-alpha clone (instead of two distinct clones sharing the same beta).

Usage

dual_discrim_dual_likelihood(est, err, numb_cells, numb_wells, binomials)

Arguments

est
Frequency estimate of the putative dual-alpha clone
err
Mean drop error rate
numb_cells
Vector containing the number of cells per well
numb_wells
Vector containing the number of wells with the sample sizes given by numb_cells
binomials
Calculations of the needed binomial coefficients; this is faster in R than in Rcpp (from my own tests)

Value

A numeric containing the negative log likelihood