dual_top() distinguishes between clones that share a common beta
chain and dual TCR clones with two productive alpha chains. The procedure
calculates the likelihood that two (alpha, beta) pairs (with common a beta
chain) come from two distinct clones sharing the same beta chain vs the
likelihood that the two pairs derive from a dual TCR-alpha clone.
A significant difference between the two likelihoods is indicative of a
dual alpha clone, and these clones are returned as dual clones.
dual_top(alpha, beta, pair, error, numb_cells)create_data.create_data.