Learn R Programming

alphabetr (version 0.2.2)

likelihood_dual: Calculate likelihood curve of frequency estimates for a dual-alpha or dual-beta TCR clone

Description

Calculate likelihood curve of frequency estimates for a dual-alpha or dual-beta TCR clone

Usage

likelihood_dual(est, err, numb_wells, numb_cells, numb_sample)

Arguments

est
Clonal frequency estimate
err
Mean drop error rate
numb_wells
A vector with the number of wells with the distinct sample sizes
numb_cells
A vector of the distinct sample sizes, i.e. the number of cells per well
numb_sample
A vector with the number of wells of the sample size of the same position of numb_cells that contains both alpha and the beta chain of the clone (for dual-alpha clones) or both beta and the alpha chain of the clone (for dual-beta clones)

Value

A numeric with the negative log likelihood