dual_discrim_shared_likelihood: Calculate likelihood of two beta-sharing candidate alpha-beta pairs deriving from a dual clone
Description
dual_discrim_shared_likelihood() is used within dual_top
to calculate the likelihood that two alpha-beta pairs identified by
bagpipe sharing the same beta chain derive from a two
distinct clones sharing the same beta chain dual-alpha clone (instead of
a single dual-alpha clone)
Usage
dual_discrim_shared_likelihood(est1, est2, err, numb_cells, numb_wells, binomials, multinomials)
Arguments
est1
Frequency estimate of the first alpha-beta clone
est2
Frequency estimate of the second alpha-beta clone
numb_cells
Vector containing the number of cells per well
numb_wells
Vector containing the number of wells with the sample
sizes given by numb_cells
binomials
Calculations of the needed binomial coefficients; this is
faster in R than in Rcpp (from my own tests)
multinomials
Calculations of the needed multinomial coefficients;
this is way faster in R due to vectorization
Value
A numeric containing the negative log likelihood