dual_eval: Calculate dual depths and false dual rates for simulated alphabetr experiments
Description
dual_eval() is used in simulation situations to compare the duals
determined by dual_top and dual_tail (which can
be combined with rbind()) to the duals in the simulated T cell
population.
Usage
dual_eval(duals, pair, TCR, number_skewed, TCR_dual)
Arguments
duals
A 4 column matrix (col 1 + 2 = beta indices, col 3 + 4 = alpha
indices) containing the indices of dual-alpha clones. The output of
dual_top and dual_tail are in this form (and
the outputs of these two functions can combined by using rbind()) TCR
The clonal structure of the simulated T cell population. This is
obtained by subsetting the TCR element of the output of
create_clones number_skewed
The number of clones represent the top proportion of
the T cell population by frequency (this is the same number_skewed
argument used when create_clones is called) TCR_dual
The dual clones of the simulated T cell population. This is
obtained by subsetting the dual_alph element of the output of
create_clones Value
A data.frame with the following columns:
-
fdr, the false dual rate
-
numb_cand_duals, the number of duals identified
-
adj_depth_top, the adjusted dual depth of top clones
-
abs_depth_top, the absolute dual depth of top clones
-
numb_correct_top, the number of correctly identified dual
clones in the top
-
numb_duals_ans_top, the number of top dual clones in the
simulated T cell population
-
numb_poss_top, the number of top dual clones whose beta and
both alpha chains were identified by bagpipe()
-
numb_unestimated_top, number of top dual clones whose
frequencies could not be calculated (usually because the clones
appeared in every well of the data)
-
adj_depth_tail, the adjusted dual depth of tail clones
-
abs_depth_tail, the absolute dual depth of tail clones
-
numb_correct_tail, the number of correctly identified tail
clones
-
numb_duals_ans_tail, the number of dual tail clones in the
simulated T cell population
-
numb_poss_tail, the number of tail dual cloens whose beta
and both alpha chains were identified by bagpipe()
-
numb_unestimated_tail, the number of tail clones whose
frequencies could not be calculated