A vector with the number of wells with the distinct
sample sizes
numb_cells
A vector of the distinct sample sizes, i.e. the number of
cells per well
numb_sample
A vector with the number of wells of the sample size of
the same position of numb_cells that contains both alpha and the
beta chain of the clone (for dual-alpha clones) or both beta and the
alpha chain of the clone (for dual-beta clones)